@@ -1,6 +1,6 @@
 /* PyWebKitGtk - Python bindings to WebKit/GTK+
  *
- * Copyright (C) 2007-2008  Jan Michael Alonzo <jmalonzo@unpluggable.com>
+ * Copyright (C) 2009  Jan Michael Alonzo <jmalonzo@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -22,17 +22,24 @@
 
 #undef _POSIX_C_SOURCE
 #include <Python.h>
-
 #include <JavaScriptCore/JSContextRef.h>
 
+typedef struct {
+    PyObject_HEAD
+    JSContextRef obj;
+} JSContextRef_object;
+
 typedef struct {
     PyObject_HEAD
     JSGlobalContextRef obj;
 } JSGlobalContextRef_object;
 
 /* Functions to wrap JavaScriptCore Python objects -> JavaScriptCore C objects */
+#define JSContextRef_get(v) (((v) == Py_None) ? NULL : (((JSContextRef_object *)(PyObject_GetAttr(v,PyString_FromString("_o"))))->obj));
+
 #define JSGlobalContextRef_get(v) (((v) == Py_None) ? NULL : (((JSGlobalContextRef_object *)(PyObject_GetAttr(v,PyString_FromString("_o"))))->obj));
 
+PyObject* wrap_JSContextRef(JSContextRef jscontextref);
 PyObject* wrap_JSGlobalContextRef(JSGlobalContextRef jsglobalref);
 
 #endif /* PYWEBKITGTK_WRAP_JSC_H */
